Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(141)

Unified Diff: src/math.js

Issue 7830036: Optimize isFinite and isNaN. (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Made the change general by moving putting it in the NUMBER_IS_FINITE macro. Created 9 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/macros.py ('k') | src/messages.js » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/math.js
diff --git a/src/math.js b/src/math.js
index b5a6d1811757aaaa7b0f35fc863b4a471e47b341..31306e79d18e1e98cba7e2ee7f697ef303f91543 100644
--- a/src/math.js
+++ b/src/math.js
@@ -195,9 +195,8 @@ function MathTan(x) {
// -------------------------------------------------------------------
-function SetUpMath() {
- %CheckIsBootstrapping();
- // Set up math constants.
+function SetupMath() {
+ // Setup math constants.
// ECMA-262, section 15.8.1.1.
%OptimizeObjectForAddingMultipleProperties($Math, 8);
%SetProperty($Math,
@@ -237,7 +236,7 @@ function SetUpMath() {
DONT_ENUM | DONT_DELETE | READ_ONLY);
%ToFastProperties($Math);
// Set up non-enumerable functions of the Math object and
// set their names.
InstallFunctionsOnHiddenPrototype($Math, DONT_ENUM, $Array(
"random", MathRandom,
@@ -259,6 +258,7 @@ function SetUpMath() {
"max", MathMax,
"min", MathMin
));
-}
+};
+
-SetUpMath();
+SetupMath();
« no previous file with comments | « src/macros.py ('k') | src/messages.js » ('j') | no next file with comments »

Powered by Google App Engine
@@ -237,7 +236,7 @@ function SetUpMath() {
DONT_ENUM | DONT_DELETE | READ_ONLY);
%ToFastProperties($Math);
- // Set up non-enumerable functions of the Math object and
+ // Setup non-enumerable functions of the Math object and
// set their names.
InstallFunctionsOnHiddenPrototype($Math, DONT_ENUM, $Array(
This is Rietveld 408576698